[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples

变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
  保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
  async_reduce, custom_temporary_allocation, explicit_cuda_stream,
  global_device_vector, range_view, unwrap_pointer, wrap_pointer, device

结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
  27/27 tuning headers, 78 benchmarks, 243 tests,
  60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
muh-bot
2026-08-03 12:39:26 +00:00
parent a2a5dd8f00
commit 24ef6a91b5
5439 changed files with 0 additions and 719516 deletions

View File

@@ -1,60 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDASTF in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
//! \file
//!
//! \brief Test ctx.wait() on a token: a blocking, value-less synchronization
#include <cuda/experimental/stf.cuh>
#include <type_traits>
using namespace cuda::experimental::stf;
__global__ void set_value(int* p, int v)
{
*p = v;
}
template <typename context_t>
void run()
{
context_t ctx;
// Externally owned buffer: STF only schedules around it, it never owns it.
int* d_val = nullptr;
cuda_safe_call(cudaMalloc(&d_val, sizeof(int)));
auto tok = ctx.token();
ctx.task(tok.write())->*[=](cudaStream_t s) {
set_value<<<1, 1, 0, s>>>(d_val, 42);
};
// wait(token) has no value to materialize: it must return void and only
// block the host until the token's producing work has completed.
static_assert(::std::is_void_v<decltype(ctx.wait(tok))>, "wait(token) must return void");
ctx.wait(tok);
int h_val = 0;
cuda_safe_call(cudaMemcpy(&h_val, d_val, sizeof(int), cudaMemcpyDeviceToHost));
_CCCL_ASSERT(h_val == 42, "wait(token) did not synchronize the producing task");
ctx.finalize();
cuda_safe_call(cudaFree(d_val));
}
int main()
{
run<stream_ctx>();
run<graph_ctx>();
run<context>();
run<stackable_ctx>();
}